@@ -3,6 +3,7 @@ from aws_cdk import (
     aws_apigateway as _apigateway,
 )
 from aws_cdk.core import Tags
+from aws_cdk_constructs.utils import normalize_environment_parameter
 
 class API(core.Construct):
     """Constuct to create API gateway
@@ -31,6 +32,7 @@ class API(core.Construct):
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
+        environment = normalize_environment_parameter(environment)
 
         # Apply mandatory tags
         Tags.of(self).add("ApplicationName", app_name.lower().strip())
