@@ -90,6 +90,8 @@ class Database(core.Construct):
 
         s3_import_buckets (Optional[Sequence[IBucket]]): S3 buckets that you want to load data from. This feature is only supported by the Aurora database engine. This property must not be used if s3ImportRole is used. For MySQL: Default: - None
 
+        rubrik_backup (str): to enable/disable Rubrik backup using tag `RubrikBackup` - format Boolean (`true`, `false`). Default: true
+
 
     """
     @property
@@ -163,6 +165,7 @@ class Database(core.Construct):
         oracle_license_is_byol=None,
         s3_export_buckets=None,
         s3_import_buckets=None,
+        rubrik_backup=True,
         **kwargs,
     ):
         super().__init__(scope, id, **kwargs)
@@ -423,6 +426,13 @@ class Database(core.Construct):
                 automatically_after=core.Duration.days(30)
             )
 
+            # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Rubrik backup tag
+
+            if rubrik_backup:
+                Tags.of(self._instance).add("RubrikBackup", "true")
+            else:
+                Tags.of(self._instance).add("RubrikBackup", "false")
+
             # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Scheduler tags
             if is_not_production:
                 instance = self._instance.node.find_child("Resource")
