@@ -137,6 +137,8 @@ class Microservice(core.Construct):
 
         load_balancer_idle_timeout_in_seconds: (Optional | str) if provided idle timeout will be  configured for the Application Load Balancer.
 
+        rubrik_backup (str): to enable/disable Rubrik backup using tag `RubrikBackup` - format Boolean (`true`, `false`). Default: true
+
     """
 
     @property
@@ -679,6 +681,7 @@ class Microservice(core.Construct):
         network_load_balancer_source_autoscaling_group=None,
         stickiness_cookie_duration_in_hours=None,
         load_balancer_idle_timeout_in_seconds=None,
+        rubrik_backup=True,
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
@@ -868,6 +871,13 @@ class Microservice(core.Construct):
                 snapshot_id=ebs_snapshot_id,
             )
 
+            # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Rubrik backup tag
+
+            if rubrik_backup:
+                Tags.of(ebs).add("RubrikBackup", "true")
+            else:
+                Tags.of(ebs).add("RubrikBackup", "false")
+
             # if is_production:
             #     ebs.add_override("DeletionPolicy", core.RemovalPolicy.SNAPSHOT)
 
@@ -1242,6 +1252,12 @@ class Microservice(core.Construct):
 
             self._efs_security_group = self.efs.node.find_child("EfsSecurityGroup")
 
+            # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Rubrik backup tag
+
+            if rubrik_backup:
+                Tags.of(self._efs).add("RubrikBackup", "true")
+            else:
+                Tags.of(self._efs).add("RubrikBackup", "false")
         # ~~~~~~~~~~~~~~~~
         # User data
         # ~~~~~~~~~~~~~~~~
@@ -1388,6 +1404,14 @@ class Microservice(core.Construct):
             ],
         )
 
+        # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Rubrik backup tag
+
+        ASG = asg.node.find_child("ASG")
+        if rubrik_backup:
+            Tags.of(ASG).add("RubrikBackup", "true", apply_to_launched_instances=True)
+        else:
+            Tags.of(ASG).add("RubrikBackup", "false", apply_to_launched_instances=True)
+
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Scheduler tags
         if is_not_production:
             ASG = asg.node.find_child("ASG")
@@ -1460,6 +1484,21 @@ class Microservice(core.Construct):
                 description="EFS access from EC2 " + app_name,
             )
 
+            if rubrik_backup:
+                rubrik_cloud_cluster_secg_id = "sg-0f80734443f5059b2"
+                production_aws_account_id = self._environments_parameters["accounts"]["production"]["id"]
+                _ec2.CfnSecurityGroupIngress(
+                    self,
+                    "self.efs_access_from_rubrik_cloud_cluster",
+                    ip_protocol = "tcp",
+                    description="EFS access from Rubrik CDM Cloud Cluster",
+                    group_id = existing_efs_security_group_resource.security_group_id,
+                    source_security_group_id = rubrik_cloud_cluster_secg_id,
+                    source_security_group_owner_id = production_aws_account_id,
+                    from_port = 2049,
+                    to_port = 2049
+                )
+
         # Add mandatory FAO security groups
         # Bastion host access
         bastion_host_security_group = _ec2.SecurityGroup.from_security_group_id(
