@@ -282,7 +282,7 @@ class ServiceUserForIAC(core.Construct):
                     ],
                     resources=["*"],
                     conditions={
-                        "ForAnyValue:StringLikeIfExists": {
+                        "ForAnyValue:StringLike": {
                             "aws:RequestTag/ApplicationName": app_name,
                         }
                     },
@@ -306,7 +306,7 @@ class ServiceUserForIAC(core.Construct):
                     ],
                     resources=["*"],
                     conditions={
-                        "ForAnyValue:StringLikeIfExists": {
+                        "ForAnyValue:StringLike": {
                              "ec2:ResourceTag/ApplicationName": app_name
                         }
                     },
@@ -317,11 +317,22 @@ class ServiceUserForIAC(core.Construct):
                     ],
                     resources=["*"],
                     conditions={
-                            "ForAnyValue:StringLikeIfExists": {
+                            "ForAnyValue:StringLike": {
                                 "ec2:ResourceTag/ApplicationName": app_name
                             }
                         },
                 ),
+                _iam.PolicyStatement(
+                    actions=[
+                        "kms:*",
+                    ],
+                    resources=["*"],
+                    conditions={
+                            "ForAnyValue:StringLike": {
+                                "aws:ResourceTag/ApplicationName": app_name
+                            }
+                        },
+                ),
                 # Filter by SPECIFIC RESOURCE
                 _iam.PolicyStatement(
                     actions=[
