@@ -5,6 +5,9 @@ def normalize_environment_parameter (environment):
         return "QA"
 
     if environment_lower == "production":
-        return "Production"
+            return "Production"
+
+    if environment_lower == "sharedservices":
+            return "SharedServices"
 
     return "Development"
\ No newline at end of file
